<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AbstractHVWidget</name>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="24"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="45"/>
        <source>Global time range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="57"/>
        <source>Time windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="68"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;If checked, a common set of windows is calculated for all items&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="74"/>
        <source>Common</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="81"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Check this option to automatically add time windows and compute spectra when new signals are available (for dynamic signals only, e.g. seedlink).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="87"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;If the signals are dynamic buffers (e.g. loaded through a SeedLink connection) and if this option is switched on, the spectral ratio results are updated every time new data are available.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="93"/>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="116"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="148"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="162"/>
        <source>all stations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="170"/>
        <source>Number of windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="190"/>
        <source>Processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="211"/>
        <source>Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="225"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Select this option when there&apos;s a strong long-period component below the frequency range of interest.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="231"/>
        <source>High-pass filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="254"/>
        <source> Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="272"/>
        <source>Horizontal components</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="278"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Conventional way of combining horizontal components&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="284"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;The real amplitude of the spectra of the horizontal components are first calculated. Then, they are combined with a squared average, and finally smoothed.&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;H=sqrt((NS^2+EW^2)/2)&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;This leads to values divided by sqrt(2) compared to Total horizontal energy option.&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;It is the conventional way of combining horizontal components (SESAME 2004), not recommended if you want to consider the amplitude of the H/V ratio. The frequency of the peak is independent of the way horizontal components are combined.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="296"/>
        <source>Squared average</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="306"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Way of combining horizontal components linked to the total energy available in horizontal wavefield.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="312"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;The real amplitude spectra of the horizontal components are first calculated. Then, they are combined with the following formula, and finally the H spectrum is smoothed.&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;H=sqrt((NS^2+EW^2))&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;H is the horizontal amplitude corresponding to the sum of the energy observed on components NS and EW.&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;The conventional way of combining horizontal components (SESAME 2004) includes a factor 1/sqrt(2), which is not recommended if you want to consider the amplitude of the H/V ratio. The frequency of the peak does not depend upon this factor.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="324"/>
        <source>Total horizontal energy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="331"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Angle counted clockwise from North.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="337"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body &gt;
&lt;p&gt;Compute the H/V ratio with an horizontal component having the direction of azimuth (counted clockwise from north).&lt;/p&gt;
&lt;p &gt;&lt;/p&gt;
&lt;p&gt;It is useful to quantify the variability of the horizontal energy along the different directions. You might be also interested by the results of the Rotated H/V (another tool provided in this plugin).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="345"/>
        <source>Directional energy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="355"/>
        <location filename="../src/AbstractHVWidget.ui" line="375"/>
        <source> °</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="368"/>
        <source>Rotation step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="408"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="414"/>
        <source>Frequency sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="441"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="452"/>
        <source>Page height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="459"/>
        <source>A5 14.9 x 21.0 (cm)
A4 21.0 x 29.7
A3 29.7 x 42.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="464"/>
        <source> cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="483"/>
        <source>Plots per line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="504"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;Automatically load a .mkup file before showing the results. The .mkup file can be created from menu &quot;Format&quot; of the sheet. It must be a &quot;sheet&quot; .mkup, not a single object .mkup (see documentation for more details).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="510"/>
        <source>Results make-up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="517"/>
        <source>Accept only make-up files for a single graph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="527"/>
        <location filename="../src/AbstractHVWidget.ui" line="561"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="538"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li {white-space: pre-wrap;}
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;Automatically load a .mkup file before showing the summary. The .mkup file can be created from menu &quot;Format&quot; of the sheet. It must be a &quot;sheet&quot; .mkup, not a single object .mkup (see documentation for more details).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="544"/>
        <source>Summary make-up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="551"/>
        <source>Accept only make-up files for a whole sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="607"/>
        <source>Load parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.ui" line="633"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HVCore::CurveResults</name>
    <message>
        <location filename="../src/CurveResults.cpp" line="54"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="86"/>
        <source>Reject time windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="86"/>
        <source>Rejected time windows are set in gray. Hit &apos;clear&apos; to effectively remove them from the processing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="178"/>
        <source>Cannot compute New Noise Model for &apos;count&apos; and &apos;V&apos; units, fix unit factors in signal headers.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="655"/>
        <location filename="../src/CurveResults.cpp" line="660"/>
        <source>File %1 already exists.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="663"/>
        <source>Saving result files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="664"/>
        <source>%1
Do you want to replace it(them)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="677"/>
        <source>Saving log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="678"/>
        <location filename="../src/CurveResults.cpp" line="692"/>
        <source>Unable to open file %1 for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="691"/>
        <source>Saving result file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="736"/>
        <source>Loading result file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="737"/>
        <source>Unable to open file %1 for reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="753"/>
        <source>Loading results file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="754"/>
        <source>Bad version, expecting version 1.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="914"/>
        <source>
No peak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/CurveResults.cpp" line="926"/>
        <source>
Category: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HVGui::AbstractHVWidget</name>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="78"/>
        <source> Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="192"/>
        <source>Common time windows disabled because sampling frequencies differ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="297"/>
        <source>%1 station(s) is/are selected in result sheet:%2
Do you want to process all station(s) or only the selected one(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="300"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="300"/>
        <source>Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="489"/>
        <location filename="../src/AbstractHVWidget.cpp" line="493"/>
        <source>Manual windowing
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="583"/>
        <source>Removing time windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="584"/>
        <source>You discarded some time windows (grayed). Do you really want to remove all windows or only the grayed ones?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="585"/>
        <source>Remove all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="585"/>
        <source>Remove grayed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="616"/>
        <source>Calculating H/V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="617"/>
        <source>No windows have been selected. Do you want to select them automatically with current parameters?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="639"/>
        <source>No window selected for station %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="645"/>
        <source>High-pass filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="646"/>
        <source>For station %1, the high-pass filter may strongly alter your results. Decrease its cut-off frequency (at least below %2).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="649"/>
        <source>Station %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="854"/>
        <source>Loading windows in log file(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="854"/>
        <source>Log file (*.log)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="872"/>
        <source>Loading windows from log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="872"/>
        <source>Only file names that match station names will be uploaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="883"/>
        <source>Loading windows in log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="884"/>
        <source>Unable to open file for reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="894"/>
        <source>Loading windows from file %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="1025"/>
        <source>Select*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="1025"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="1047"/>
        <source>Make-up for results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="1047"/>
        <location filename="../src/AbstractHVWidget.cpp" line="1054"/>
        <source>Sheet make-up (*.mkup)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/AbstractHVWidget.cpp" line="1054"/>
        <source>Make-up for summary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
